# -*- coding: utf-8 -*-
# tcp.py
#
# Coded by: Koji KITANO <koji.kitano52@gmail.com>,
# Human Systems Laboratory, Department of Systems Science,
# Graduate School of Informatics, Kyoto University.

import json
import socket

""" TCPサーバを立てて，リクエストに応じて天気や時間の情報を返すコード """

class Server():
    """ TCPサーバ """
    def __init__(self, port=50008):
        # ポート番号
        self.port = port

        # 送信するデータを格納する配列
        self.frames = []

    def listen(self):

        # ソケットモジュール
        self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        # サーバを立てる
        self.socket.bind(("", self.port))
        # 待受を可能にする
        self.socket.listen()
        # 接続を待ち受ける．接続されたら通信用のソケットで上書き
        self.socket, self.client_addr = self.socket.accept()

import datetime
from get_weather import get_weather
from get_geolocation import get_geolocation

class WeatherTimeServer(Server):
    """ TCPサーバを継承・お天気/時間サーバ"""
    def send_data(self):
        request = self.socket.recv(1024).decode('utf-8')
        print(request)

        if request == 'w':
            location = get_geolocation()
            res = str(get_weather(*location))
        elif request == 't':
            dt = datetime.datetime.today()
            res = str(dt.year) + ',' + str(dt.month) + ',' + str(dt.day) + ',' + str(dt.hour) + ',' + str(dt.minute) + ',' + str(dt.second)
        else:
            res = 'Invalid request'

        res = res.encode('utf-8')

        self.socket.send(res)


if __name__ == '__main__':
    server = WeatherTimeServer()
    server.listen()

    while True:
        server.send_data()
